is_cache_fresh

Function is_cache_fresh 

pub fn is_cache_fresh(cache_path: &Path, save_path: &Path) -> bool
Check if the cache file is fresh relative to the save file.

Returns true if the cache exists and is newer than the save file. Returns false if the cache is missing, older than the save, or if timestamps can’t be read.