pub struct CachedSystem {
pub address: GalacticAddress,
pub name: Option<String>,
pub discoverer: Option<String>,
pub timestamp_secs: Option<i64>,
pub planets: Vec<Planet>,
}Expand description
A system with flattened fields for cache storage.
We flatten System rather than embedding it because System contains
Option<DateTime<Utc>> which doesn’t support rkyv. Timestamps are
stored as Unix seconds and converted on load.
Fields
address: GalacticAddressname: Option<String>discoverer: Option<String>timestamp_secs: Option<i64>Timestamp as Unix seconds (converted from DateTime<Utc>).
planets: Vec<Planet>Trait Implementations
Sourceimpl Archive for CachedSystem
impl Archive for CachedSystem
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedCachedSystem
type Archived = ArchivedCachedSystem
The archived representation of this type. Read more
Sourcetype Resolver = CachedSystemResolver
type Resolver = CachedSystemResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Debug for CachedSystem
impl Debug for CachedSystem
Sourceimpl<__D: Fallible + ?Sized> Deserialize<CachedSystem, __D> for Archived<CachedSystem>where
GalacticAddress: Archive,
<GalacticAddress as Archive>::Archived: Deserialize<GalacticAddress, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
Option<i64>: Archive,
<Option<i64> as Archive>::Archived: Deserialize<Option<i64>, __D>,
Vec<Planet>: Archive,
<Vec<Planet> as Archive>::Archived: Deserialize<Vec<Planet>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<CachedSystem, __D> for Archived<CachedSystem>where
GalacticAddress: Archive,
<GalacticAddress as Archive>::Archived: Deserialize<GalacticAddress, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
Option<i64>: Archive,
<Option<i64> as Archive>::Archived: Deserialize<Option<i64>, __D>,
Vec<Planet>: Archive,
<Vec<Planet> as Archive>::Archived: Deserialize<Vec<Planet>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<CachedSystem, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<CachedSystem, <__D as Fallible>::Error>
Deserializes using the given deserializer